# Dockerfile for Allegra on Debian
FROM allegrapm/base-tex:latest
LABEL maintainer="Steinbeis GmbH & Co. KG (support@trackplus.com)"
LABEL version=latest-dist

ENV TRACKBURL=https://www.trackplus.com/files/downloads/latest-dist/core
ENV TRACKURL=$TRACKBURL/allegra-latest.war

ENV TRACKVURL=$TRACKBURL/Version.properties
ENV CONTEXT="allegra"

# Add Allegra to the container
ARG CACHEBUST=1
RUN set -ex; \
        mkdir /usr/local/tomcat/webapps-store ; \
        wget --progress=dot:giga $TRACKURL -O /usr/local/tomcat/webapps-store/allegra.war ; \
        wget --progress=dot:binary $TRACKVURL -O /tmp/Version.properties ; \
        VERSION=`grep "^version=" /tmp/Version.properties | cut -c9-`; \
        echo "Build Allegra $VERSION container" ; \
        cd /usr/local/tomcat/conf ; \
        sed -i context.xml -e "s%</Context>%<Resources cachingAllowed=\"true\" cacheMaxSize=\"100000\" /></Context>%g" ;\
	sed -i server.xml -e "s%port=\"8009\"%asyncTimeout=\"20000\" maxPostSize=\"40000000\" port=\"8009\"%g" ;\
	sed -i server.xml -e "s%connectionTimeout%asyncTimeout=\"20000\" maxPostSize=\"40000000\" connectionTimeout%g"  

# Create a context setting and startup script
RUN set -ex; \
        mkdir /home/track ;\
        TCCONF=/usr/local/tomcat/conf; \
        echo "#!/bin/bash"                 > $TCCONF/entry.sh; \
        echo "echo \"torque.dsfactory.track.connection.user = \$DBUSER\" > /home/track/Torque.properties  " >> $TCCONF/entry.sh; \
        echo "echo \"torque.dsfactory.track.connection.password = \$DBPASSWD\" >> /home/track/Torque.properties  " >> $TCCONF/entry.sh; \
        echo "echo \"torque.database.track.adapter=mysql\" >> /home/track/Torque.properties " >> $TCCONF/entry.sh; \
        echo "echo \"torque.dsfactory.track.connection.driver = org.gjt.mm.mysql.Driver\" >> /home/track/Torque.properties  " >> $TCCONF/entry.sh; \
        echo "echo \"torque.dsfactory.track.connection.url = jdbc:mysql://mysql-\$CONTEXT:3306/track?serverTimezone=UTC&useSSL=false&useUnicode=true&characterEncoding=UTF-8&zeroDateTimeBehavior=convertToNull\" >> /home/track/Torque.properties " >> $TCCONF/entry.sh; \
        echo "echo \"torque.dsfactory.track.factory=org.apache.torque.dsfactory.SharedPoolDataSourceFactory\" >> /home/track/Torque.properties " >> $TCCONF/entry.sh; \
        echo "echo \"torque.dsfactory.track.pool.maxActive=30\" >> /home/track/Torque.properties " >> $TCCONF/entry.sh; \
        echo "echo \"torque.dsfactory.track.pool.testOnBorrow=true\" >> /home/track/Torque.properties " >> $TCCONF/entry.sh; \
        echo "echo \"torque.dsfactory.track.pool.validationQuery=SELECT PKEY FROM TSTATE\" >> /home/track/Torque.properties " >> $TCCONF/entry.sh; \
        echo "env" >> $TCCONF/entry.sh; \
        echo "if [ \"\$CONTEXT\" == \"\" ]; then " >> $TCCONF/entry.sh; \
        echo "  CONTEXT=allegra"  >> $TCCONF/entry.sh; \
        echo "fi " >> $TCCONF/entry.sh; \
        echo "TCBASE=/usr/local/tomcat"  >> $TCCONF/entry.sh; \
        echo "mkdir -p \$TCBASE/conf/Catalina/localhost " >> $TCCONF/entry.sh; \
        contexts="<Context path=\\\"/\$CONTEXT\\\" docBase=\\\"\$TCBASE/webapps-store/allegra.war\\\"/> " ; \
        echo "echo \"$contexts\" > \$TCBASE/conf/Catalina/localhost/\$CONTEXT.xml " >> $TCCONF/entry.sh; \
        echo "echo \"Using context \$CONTEXT\" " >> $TCCONF/entry.sh; \
        echo "cd /usr/local/tomcat/bin; ./catalina.sh run" >> $TCCONF/entry.sh; \
	echo "until nc -z -v -w30 $CFG_MYSQL_HOST 3306" >> $TCCONF/entry.sh; \
	echo "do" >> $TCCONF/entry.sh; \
	echo "  echo 'Waiting for database connection...'" >> $TCCONF/entry.sh; \
	echo "  sleep 5 " >> $TCCONF/entry.sh; \
	echo "done " >> $TCCONF/entry.sh; \
        chmod 755 $TCCONF/entry.sh 

CMD [ "/bin/bash", "-c", "cd /opt/allegra-print-server/ && ./startStop.sh start && /usr/local/tomcat/conf/entry.sh" ]
